@@ -6,7 +6,7 @@ from typing import IO, Optional
 import click
 
 import proofaday.constants as consts
-import proofaday.message as message
+from proofaday import message
 from proofaday.cli_util import ClickPath
 from proofaday.message import Message
 from proofaday.status import Status
@@ -28,8 +28,8 @@ class ProofClient:
                 sock.sendto(msg.encode(), (self.host, self.port))
                 sock.settimeout(self.timeout)
                 return sock.recv(4096).decode()
-            except socket.timeout:
-                raise ClientError("Connection timed out.")
+            except socket.timeout as e:
+                raise ClientError("Connection timed out.") from e
 
     def query(self, proof: Optional[str]) -> str:
         if proof is not None:
@@ -38,14 +38,14 @@ class ProofClient:
 
 
 @click.command(help="Fetch a random proof.")
-@click.argument("proof", required=False, default=None)
-@click.option(
+@click.argument("proof", required=False, default=None)  # type: ignore[misc]
+@click.option(  # type: ignore[misc]
     "--status-path",
     help="Directory to place the status file.",
     type=ClickPath(exists=False, file_okay=False),
     default=consts.DATA_PATH,
 )
-@click.option(
+@click.option(  # type: ignore[misc]
     "-t",
     "--timeout",
     help="Time to wait for a proof (in seconds).",
@@ -53,7 +53,7 @@ class ProofClient:
     default=consts.CLIENT_TIMEOUT,
     show_default=True,
 )
-@click.option(
+@click.option(  # type: ignore[misc]
     "-o",
     "--output",
     help="The file to print output to.",
@@ -78,4 +78,5 @@ def main(
 
 
 if __name__ == "__main__":
+    # pylint: disable=no-value-for-parameter
     main()
